@@ -2,7 +2,7 @@ require 5.006;
 use strict;
 use warnings;
 package Email::Valid;
-$Email::Valid::VERSION = '1.195';
+$Email::Valid::VERSION = '1.197';
 # ABSTRACT: Check validity of Internet email addresses
 our (
   $RFC822PAT,
@@ -75,7 +75,7 @@ sub _rearrange {
   ref $self ? %args = %$self : _initialize( \%args );
   return %args unless @params;
 
-  unless ($params[0] =~ /^-/ and @params > 1) {
+  unless (@params > 1 and $params[0] =~ /^-/) {
     while(@params) {
       croak 'unexpected number of parameters' unless @names;
       $args{ lc shift @names } = shift @params;
@@ -144,22 +144,18 @@ sub _net_dns_query {
 
   $Resolver = Net::DNS::Resolver->new unless defined $Resolver;
 
-  my $packet = $Resolver->send($host, 'MX') or croak $Resolver->errorstring;
-  if ($packet->header->ancount) {
-    my @mx_entries = grep { $_->type eq 'MX' } $packet->answer;
-    if(@mx_entries) {
-        my $mx = ($mx_entries[0])->exchange;
-        if ($mx eq '.' or $mx eq '') {
-          return $self->details('mx'); # Null MX
-        } else {
-          return 1;
-        }
+  my @mx_entries = Net::DNS::mx($Resolver, $host);
+
+  if (@mx_entries) {
+    foreach my $mx (@mx_entries) {
+      my $mxhost = $mx->exchange;
+      my $query = $Resolver->search($mx);
+      foreach my $a_rr ($query->answer) {
+        return 1 unless $a_rr->type ne 'A';
+      }
     }
   }
 
-  $packet = $Resolver->send($host, 'A') or croak $Resolver->errorstring;
-  return 1 if $packet->header->ancount;
-
   return $self->details('mx');
 }
 
@@ -281,16 +277,6 @@ sub _local_rules {
   my $self = shift;
   my($user, $host) = @_;
 
-  # AOL addresses cannot:
-  #     - Be shorter than 3 or longer than 16 characters
-  #     - Begin with numerals
-  #     - Contain periods, underscores, dashes or other punctuation characters
-  #
-  # http://postmaster.info.aol.com/faq.html
-  # Last updated: Aug 23, 2003
-  if ($host =~ /aol\.com/i) {
-    return undef unless $user =~ /^[a-zA-Z][a-zA-Z0-9]{2,15}$/;
-  }
   1;
 }
 
@@ -719,7 +705,7 @@ Email::Valid - Check validity of Internet email addresses
 
 =head1 VERSION
 
-version 1.195
+version 1.197
 
 =head1 SYNOPSIS
 
@@ -930,6 +916,46 @@ Mail::Address, Net::DNS, Net::Domain::TLD, perlfaq9
 
 Maurice Aubrey <maurice@hevanet.com>
 
+=head1 CONTRIBUTORS
+
+=for stopwords Alexandr Ciornii Karel Miko McA Michael Schout Ricardo SIGNES Signes Svetlana Troy Morehouse
+
+=over 4
+
+=item *
+
+Alexandr Ciornii <alexchorny@gmail.com>
+
+=item *
+
+Karel Miko <karel.miko@gmail.com>
+
+=item *
+
+McA <McA@github.com>
+
+=item *
+
+Michael Schout <mschout@gkg.net>
+
+=item *
+
+Ricardo SIGNES <rjbs@cpan.org>
+
+=item *
+
+Ricardo Signes <rjbs@cpan.org>
+
+=item *
+
+Svetlana <svetlana.wiczer@gmail.com>
+
+=item *
+
+Troy Morehouse <troymore@nbnet.nb.ca>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 1998 by Maurice Aubrey.
